==> mingw-w64-aws-sdk-cpp-1.9.338-1.src.tar.zst: aws-sdk-cpp-1.9.338/aws-cpp-sdk-ec2/include/aws/ec2/model/InstanceSpecification.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/ec2/EC2_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSStreamFwd.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Xml
{
  class XmlNode;
} // namespace Xml
} // namespace Utils
namespace EC2
{
namespace Model
{

  /**
   * <p>The instance details to specify which volumes should be
   * snapshotted.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/InstanceSpecification">AWS
   * API Reference</a></p>
   */
  class AWS_EC2_API InstanceSpecification
  {
  public:
    InstanceSpecification();
    InstanceSpecification(const Aws::Utils::Xml::XmlNode& xmlNode);
    InstanceSpecification& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);

    void OutputToStream(Aws::OStream& ostream, const char* location, unsigned index, const char* locationValue) const;
    void OutputToStream(Aws::OStream& oStream, const char* location) const;


    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline const Aws::String& GetInstanceId() const{ return m_instanceId; }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline bool InstanceIdHasBeenSet() const { return m_instanceIdHasBeenSet; }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline void SetInstanceId(const Aws::String& value) { m_instanceIdHasBeenSet = true; m_instanceId = value; }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline void SetInstanceId(Aws::String&& value) { m_instanceIdHasBeenSet = true; m_instanceId = std::move(value); }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline void SetInstanceId(const char* value) { m_instanceIdHasBeenSet = true; m_instanceId.assign(value); }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline InstanceSpecification& WithInstanceId(const Aws::String& value) { SetInstanceId(value); return *this;}

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline InstanceSpecification& WithInstanceId(Aws::String&& value) { SetInstanceId(std::move(value)); return *this;}

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline InstanceSpecification& WithInstanceId(const char* value) { SetInstanceId(value); return *this;}


    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline bool GetExcludeBootVolume() const{ return m_excludeBootVolume; }

    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline bool ExcludeBootVolumeHasBeenSet() const { return m_excludeBootVolumeHasBeenSet; }

    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline void SetExcludeBootVolume(bool value) { m_excludeBootVolumeHasBeenSet = true; m_excludeBootVolume = value; }

    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline InstanceSpecification& WithExcludeBootVolume(bool value) { SetExcludeBootVolume(value); return *this;}


    
    inline const Aws::Vector<Aws::String>& GetExcludeDataVolumeIds() const{ return m_excludeDataVolumeIds; }

    
    inline bool ExcludeDataVolumeIdsHasBeenSet() const { return m_excludeDataVolumeIdsHasBeenSet; }

    
    inline void SetExcludeDataVolumeIds(const Aws::Vector<Aws::String>& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds = value; }

    
    inline void SetExcludeDataVolumeIds(Aws::Vector<Aws::String>&& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds = std::move(value); }

    
    inline InstanceSpecification& WithExcludeDataVolumeIds(const Aws::Vector<Aws::String>& value) { SetExcludeDataVolumeIds(value); return *this;}

    
    inline InstanceSpecification& WithExcludeDataVolumeIds(Aws::Vector<Aws::String>&& value) { SetExcludeDataVolumeIds(std::move(value)); return *this;}

    
    inline InstanceSpecification& AddExcludeDataVolumeIds(const Aws::String& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds.push_back(value); return *this; }

    
    inline InstanceSpecification& AddExcludeDataVolumeIds(Aws::String&& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds.push_back(std::move(value)); return *this; }

    
    inline InstanceSpecification& AddExcludeDataVolumeIds(const char* value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds.push_back(value); return *this; }

  private:

    Aws::String m_instanceId;
    bool m_instanceIdHasBeenSet;

    bool m_excludeBootVolume;
    bool m_excludeBootVolumeHasBeenSet;

    Aws::Vector<Aws::String> m_excludeDataVolumeIds;
    bool m_excludeDataVolumeIdsHasBeenSet;
  };

} // namespace Model
} // namespace EC2
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.9.348-1.src.tar.zst: aws-sdk-cpp-1.9.348/aws-cpp-sdk-ec2/include/aws/ec2/model/InstanceSpecification.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/ec2/EC2_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSStreamFwd.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Xml
{
  class XmlNode;
} // namespace Xml
} // namespace Utils
namespace EC2
{
namespace Model
{

  /**
   * <p>The instance details to specify which volumes should be
   * snapshotted.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/InstanceSpecification">AWS
   * API Reference</a></p>
   */
  class AWS_EC2_API InstanceSpecification
  {
  public:
    InstanceSpecification();
    InstanceSpecification(const Aws::Utils::Xml::XmlNode& xmlNode);
    InstanceSpecification& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);

    void OutputToStream(Aws::OStream& ostream, const char* location, unsigned index, const char* locationValue) const;
    void OutputToStream(Aws::OStream& oStream, const char* location) const;


    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline const Aws::String& GetInstanceId() const{ return m_instanceId; }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline bool InstanceIdHasBeenSet() const { return m_instanceIdHasBeenSet; }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline void SetInstanceId(const Aws::String& value) { m_instanceIdHasBeenSet = true; m_instanceId = value; }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline void SetInstanceId(Aws::String&& value) { m_instanceIdHasBeenSet = true; m_instanceId = std::move(value); }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline void SetInstanceId(const char* value) { m_instanceIdHasBeenSet = true; m_instanceId.assign(value); }

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline InstanceSpecification& WithInstanceId(const Aws::String& value) { SetInstanceId(value); return *this;}

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline InstanceSpecification& WithInstanceId(Aws::String&& value) { SetInstanceId(std::move(value)); return *this;}

    /**
     * <p>The instance to specify which volumes should be snapshotted.</p>
     */
    inline InstanceSpecification& WithInstanceId(const char* value) { SetInstanceId(value); return *this;}


    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline bool GetExcludeBootVolume() const{ return m_excludeBootVolume; }

    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline bool ExcludeBootVolumeHasBeenSet() const { return m_excludeBootVolumeHasBeenSet; }

    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline void SetExcludeBootVolume(bool value) { m_excludeBootVolumeHasBeenSet = true; m_excludeBootVolume = value; }

    /**
     * <p>Excludes the root volume from being snapshotted.</p>
     */
    inline InstanceSpecification& WithExcludeBootVolume(bool value) { SetExcludeBootVolume(value); return *this;}


    
    inline const Aws::Vector<Aws::String>& GetExcludeDataVolumeIds() const{ return m_excludeDataVolumeIds; }

    
    inline bool ExcludeDataVolumeIdsHasBeenSet() const { return m_excludeDataVolumeIdsHasBeenSet; }

    
    inline void SetExcludeDataVolumeIds(const Aws::Vector<Aws::String>& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds = value; }

    
    inline void SetExcludeDataVolumeIds(Aws::Vector<Aws::String>&& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds = std::move(value); }

    
    inline InstanceSpecification& WithExcludeDataVolumeIds(const Aws::Vector<Aws::String>& value) { SetExcludeDataVolumeIds(value); return *this;}

    
    inline InstanceSpecification& WithExcludeDataVolumeIds(Aws::Vector<Aws::String>&& value) { SetExcludeDataVolumeIds(std::move(value)); return *this;}

    
    inline InstanceSpecification& AddExcludeDataVolumeIds(const Aws::String& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds.push_back(value); return *this; }

    
    inline InstanceSpecification& AddExcludeDataVolumeIds(Aws::String&& value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds.push_back(std::move(value)); return *this; }

    
    inline InstanceSpecification& AddExcludeDataVolumeIds(const char* value) { m_excludeDataVolumeIdsHasBeenSet = true; m_excludeDataVolumeIds.push_back(value); return *this; }

  private:

    Aws::String m_instanceId;
    bool m_instanceIdHasBeenSet = false;

    bool m_excludeBootVolume;
    bool m_excludeBootVolumeHasBeenSet = false;

    Aws::Vector<Aws::String> m_excludeDataVolumeIds;
    bool m_excludeDataVolumeIdsHasBeenSet = false;
  };

} // namespace Model
} // namespace EC2
} // namespace Aws
